@@ -2,7 +2,6 @@
 
 use std::collections::HashMap;
 
-use log::*;
 use maplit::hashmap;
 use pact_models::content_types::ContentType;
 use pact_models::json_utils::json_to_string;
@@ -16,6 +15,7 @@ use pact_plugin_driver::catalogue_manager::find_content_matcher;
 use pact_plugin_driver::content::{ContentMatcher, InteractionContents, PluginConfiguration};
 use pact_plugin_driver::plugin_models::PactPluginManifest;
 use serde_json::{json, Map, Value};
+use tracing::debug;
 
 use crate::prelude::{JsonPattern, Pattern};
 
